@@ -173,16 +173,16 @@ class IPFabricTransformMapSourceModelChoices(ChoiceSet):
     PARTNUMBERS = "part_number"
 
     CHOICES = (
-        (SITE, "Site", "cyan"),
-        (INVENTORY, "Inventory", "gray"),
-        (DEVICE, "Device", "gray"),
-        (VIRTUALCHASSIS, "Virtual Chassis", "grey"),
-        (INTERFACE, "Interface", "gray"),
-        (VLAN, "VLAN", "gray"),
-        (VRF, "VRF", "gray"),
-        (PREFIX, "Prefix", "gray"),
-        (IPADDRESS, "IP Address", "gray"),
-        (PARTNUMBERS, "Part Number", "gray"),
+        (SITE, _("Site"), "cyan"),
+        (INVENTORY, _("Inventory"), "gray"),
+        (DEVICE, _("Device"), "gray"),
+        (VIRTUALCHASSIS, _("Virtual Chassis"), "grey"),
+        (INTERFACE, _("Interface"), "gray"),
+        (VLAN, _("VLAN"), "gray"),
+        (VRF, _("VRF"), "gray"),
+        (PREFIX, _("Prefix"), "gray"),
+        (IPADDRESS, _("IP Address"), "gray"),
+        (PARTNUMBERS, _("Part Number"), "gray"),
     )
 
 
@@ -203,8 +203,8 @@ class IPFabricSourceTypeChoices(ChoiceSet):
     REMOTE = "remote"
 
     CHOICES = (
-        (LOCAL, "Local", "cyan"),
-        (REMOTE, "Remote", "gray"),
+        (LOCAL, _("Local"), "cyan"),
+        (REMOTE, _("Remote"), "gray"),
     )
 
 
@@ -220,12 +220,48 @@ class IPFabricRawDataTypeChoices(ChoiceSet):
     SITE = "site"
 
     CHOICES = (
-        (DEVICE, "Local", "cyan"),
-        (VLAN, "VLAN", "gray"),
-        (VIRTUALCHASSIS, "Virtual Chassis", "gray"),
-        (PREFIX, "Prefix", "gray"),
-        (INTERFACE, "Interface", "gray"),
-        (INVENTORYITEM, "Inventory Item", "gray"),
-        (IPADDRESS, "IP Address", "gray"),
-        (SITE, "Site", "gray"),
+        (DEVICE, _("Local"), "cyan"),
+        (VLAN, _("VLAN"), "gray"),
+        (VIRTUALCHASSIS, _("Virtual Chassis"), "gray"),
+        (PREFIX, _("Prefix"), "gray"),
+        (INTERFACE, _("Interface"), "gray"),
+        (INVENTORYITEM, _("Inventory Item"), "gray"),
+        (IPADDRESS, _("IP Address"), "gray"),
+        (SITE, _("Site"), "gray"),
+    )
+
+
+class IPFabricSourceStatusChoices(ChoiceSet):
+    NEW = "new"
+    QUEUED = "queued"
+    SYNCING = "syncing"
+    COMPLETED = "completed"
+    FAILED = "failed"
+
+    CHOICES = (
+        (NEW, _("New"), "blue"),
+        (QUEUED, _("Queued"), "orange"),
+        (SYNCING, _("Syncing"), "cyan"),
+        (COMPLETED, _("Completed"), "green"),
+        (FAILED, _("Failed"), "red"),
+    )
+
+
+class IPFabricSyncStatusChoices(ChoiceSet):
+    NEW = "new"
+    QUEUED = "queued"
+    SYNCING = "syncing"
+    READY_TO_MERGE = "ready_to_merge"
+    MERGING = "merging"
+    COMPLETED = "completed"
+    FAILED = "failed"
+
+    CHOICES = (
+        (NEW, _("New"), "blue"),
+        (QUEUED, _("Queued"), "orange"),
+        (SYNCING, _("Syncing"), "cyan"),
+        (READY_TO_MERGE, _("Ready to merge"), "purple"),
+        (MERGING, _("Merging"), "cyan"),
+        (COMPLETED, _("Completed"), "green"),
+        (FAILED, _("Failed"), "red"),
     )
