@@ -1,15 +1,17 @@
 import strawberry
-from core.choices import DataSourceStatusChoices
 from core.choices import JobStatusChoices
 from netbox_branching.choices import BranchStatusChoices
 
 from ipfabric_netbox.choices import IPFabricRawDataTypeChoices
 from ipfabric_netbox.choices import IPFabricSnapshotStatusModelChoices
+from ipfabric_netbox.choices import IPFabricSourceStatusChoices
 from ipfabric_netbox.choices import IPFabricSourceTypeChoices
+from ipfabric_netbox.choices import IPFabricSyncStatusChoices
 from ipfabric_netbox.choices import IPFabricTransformMapSourceModelChoices
 
 __all__ = (
-    "DataSourceStatusEnum",
+    "IPFabricSourceStatusEnum",
+    "IPFabricSyncStatusEnum",
     "IPFabricTransformMapSourceModelEnum",
     "IPFabricSourceTypeEnum",
     "IPFabricSnapshotStatusModelEnum",
@@ -18,7 +20,12 @@ __all__ = (
     "JobStatusEnum",
 )
 
-DataSourceStatusEnum = strawberry.enum(DataSourceStatusChoices.as_enum(prefix="type"))
+IPFabricSourceStatusEnum = strawberry.enum(
+    IPFabricSourceStatusChoices.as_enum(prefix="type")
+)
+IPFabricSyncStatusEnum = strawberry.enum(
+    IPFabricSyncStatusChoices.as_enum(prefix="type")
+)
 IPFabricTransformMapSourceModelEnum = strawberry.enum(
     IPFabricTransformMapSourceModelChoices.as_enum(prefix="type")
 )
