@@ -7,7 +7,6 @@ from copy import deepcopy
 from uuid import uuid4
 
 import httpx
-from core.choices import DataSourceStatusChoices
 from core.choices import JobStatusChoices
 from core.exceptions import SyncError
 from core.models import Job
@@ -46,7 +45,9 @@ from utilities.request import NetBoxFakeRequest
 
 from .choices import IPFabricRawDataTypeChoices
 from .choices import IPFabricSnapshotStatusModelChoices
+from .choices import IPFabricSourceStatusChoices
 from .choices import IPFabricSourceTypeChoices
+from .choices import IPFabricSyncStatusChoices
 from .choices import IPFabricTransformMapSourceModelChoices
 from .choices import required_transform_map_contenttypes
 from .signals import clear_other_primary_ip
@@ -104,8 +105,8 @@ class IPFabricTransformMapGroup(NetBoxModel):
 
     class Meta:
         ordering = ("pk",)
-        verbose_name = "IP Fabric Transform Map Group"
-        verbose_name_plural = "IP Fabric Transform Map Groups"
+        verbose_name = _("IP Fabric Transform Map Group")
+        verbose_name_plural = _("IP Fabric Transform Map Groups")
 
     def __str__(self):
         return self.name
@@ -124,7 +125,7 @@ class IPFabricTransformMap(NetBoxModel):
     target_model = models.ForeignKey(
         to=ContentType,
         related_name="+",
-        verbose_name="Target Model",
+        verbose_name=_("Target Model"),
         limit_choices_to=IPFabricSupportedSyncModels,
         help_text=_("The object(s) to which transform map target applies."),
         on_delete=models.PROTECT,
@@ -141,8 +142,8 @@ class IPFabricTransformMap(NetBoxModel):
 
     class Meta:
         ordering = ("pk",)
-        verbose_name = "IP Fabric Transform Map"
-        verbose_name_plural = "IP Fabric Transform Maps"
+        verbose_name = _("IP Fabric Transform Map")
+        verbose_name_plural = _("IP Fabric Transform Maps")
 
     def __str__(self):
         if self.source_model and self.target_model:
@@ -336,7 +337,7 @@ class IPFabricRelationshipField(models.Model):
         ContentType,
         related_name="ipfabric_transform_fields",
         limit_choices_to=IPFabricRelationshipFieldSourceModels,
-        verbose_name="Source Model",
+        verbose_name=_("Source Model"),
         on_delete=models.PROTECT,
         blank=False,
         null=False,
@@ -355,8 +356,8 @@ class IPFabricRelationshipField(models.Model):
 
     class Meta:
         ordering = ("transform_map",)
-        verbose_name = "IP Fabric Relationship Field"
-        verbose_name_plural = "IP Fabric Relationship Fields"
+        verbose_name = _("IP Fabric Relationship Field")
+        verbose_name_plural = _("IP Fabric Relationship Fields")
 
     @property
     def docs_url(self):
@@ -385,8 +386,8 @@ class IPFabricTransformField(models.Model):
 
     class Meta:
         ordering = ("transform_map",)
-        verbose_name = "IP Fabric Transform Field"
-        verbose_name_plural = "IP Fabric Transform Fields"
+        verbose_name = _("IP Fabric Transform Field")
+        verbose_name_plural = _("IP Fabric Transform Fields")
 
     @property
     def docs_url(self):
@@ -418,7 +419,7 @@ class IPFabricClient:
             self.handle_sync_failure("Error", e)
 
     def handle_sync_failure(self, failure_type, exception, message=None):
-        self.status = DataSourceStatusChoices.FAILED
+        self.status = IPFabricSyncStatusChoices.FAILED
 
         if message:
             self.logger.log_failure(
@@ -439,8 +440,8 @@ class IPFabricSource(IPFabricClient, JobsMixin, PrimaryModel):
     url = models.CharField(max_length=200, verbose_name=_("URL"))
     status = models.CharField(
         max_length=50,
-        choices=DataSourceStatusChoices,
-        default=DataSourceStatusChoices.NEW,
+        choices=IPFabricSourceStatusChoices,
+        default=IPFabricSourceStatusChoices.NEW,
         editable=False,
     )
     parameters = models.JSONField(blank=True, null=True)
@@ -448,8 +449,8 @@ class IPFabricSource(IPFabricClient, JobsMixin, PrimaryModel):
 
     class Meta:
         ordering = ("name",)
-        verbose_name = "IP Fabric Source"
-        verbose_name_plural = "IP Fabric Sources"
+        verbose_name = _("IP Fabric Source")
+        verbose_name_plural = _("IP Fabric Sources")
 
     def __str__(self):
         return f"{self.name}"
@@ -460,8 +461,8 @@ class IPFabricSource(IPFabricClient, JobsMixin, PrimaryModel):
     @property
     def ready_for_sync(self):
         return self.status not in (
-            DataSourceStatusChoices.QUEUED,
-            DataSourceStatusChoices.SYNCING,
+            IPFabricSourceStatusChoices.QUEUED,
+            IPFabricSourceStatusChoices.SYNCING,
         )
 
     @property
@@ -476,7 +477,7 @@ class IPFabricSource(IPFabricClient, JobsMixin, PrimaryModel):
 
     def enqueue_sync_job(self, request):
         # Set the status to "syncing"
-        self.status = DataSourceStatusChoices.QUEUED
+        self.status = IPFabricSourceStatusChoices.QUEUED
         IPFabricSource.objects.filter(pk=self.pk).update(status=self.status)
 
         # Enqueue a sync job
@@ -489,7 +490,7 @@ class IPFabricSource(IPFabricClient, JobsMixin, PrimaryModel):
 
     def sync(self, job):
         self.logger = SyncLogging(job=job.pk)
-        if self.status == DataSourceStatusChoices.SYNCING:
+        if self.status == IPFabricSourceStatusChoices.SYNCING:
             self.logger.log_failure(
                 "Cannot initiate sync; syncing already in progress.", obj=self
             )
@@ -497,7 +498,7 @@ class IPFabricSource(IPFabricClient, JobsMixin, PrimaryModel):
 
         pre_sync.send(sender=self.__class__, instance=self)
 
-        self.status = DataSourceStatusChoices.SYNCING
+        self.status = IPFabricSourceStatusChoices.SYNCING
         IPFabricSource.objects.filter(pk=self.pk).update(status=self.status)
 
         # Begin Sync
@@ -542,7 +543,7 @@ class IPFabricSource(IPFabricClient, JobsMixin, PrimaryModel):
                         f"Created/Updated Snapshot {snapshot.name} ({snapshot.snapshot_id})",
                         obj=snapshot,  # noqa E225
                     )
-            self.status = DataSourceStatusChoices.COMPLETED
+            self.status = IPFabricSourceStatusChoices.COMPLETED
             self.logger.log_success(f"Completed syncing snapshots from {self.name}")
             logger.debug(f"Completed syncing snapshots from {self.url}")
         except Exception as e:
@@ -587,8 +588,8 @@ class IPFabricSnapshot(TagsMixin, ChangeLoggedModel):
 
     class Meta:
         ordering = ("source", "-date")
-        verbose_name = "IP Fabric Snapshot"
-        verbose_name_plural = "IP Fabric Snapshots"
+        verbose_name = _("IP Fabric Snapshot")
+        verbose_name_plural = _("IP Fabric Snapshots")
 
     def __str__(self):
         return f"{self.name} - {self.snapshot_id}"
@@ -621,8 +622,8 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
     )
     status = models.CharField(
         max_length=50,
-        choices=DataSourceStatusChoices,
-        default=DataSourceStatusChoices.NEW,
+        choices=IPFabricSyncStatusChoices,
+        default=IPFabricSyncStatusChoices.NEW,
         editable=False,
     )
     parameters = models.JSONField(blank=True, null=True)
@@ -646,7 +647,7 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
 
     class Meta:
         ordering = ["pk"]
-        verbose_name = "IP Fabric Sync"
+        verbose_name = _("IP Fabric Sync")
 
     def __str__(self):
         return f"{self.name}"
@@ -668,7 +669,7 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
         return reverse("plugins:ipfabric_netbox:ipfabricsync", args=[self.pk])
 
     def get_status_color(self):
-        return DataSourceStatusChoices.colors.get(self.status)
+        return IPFabricSyncStatusChoices.colors.get(self.status)
 
     def save(self, *args, **kwargs):
         super().save(*args, **kwargs)
@@ -677,7 +678,7 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
 
     @property
     def ready_for_sync(self):
-        if self.status not in (DataSourceStatusChoices.SYNCING,):
+        if self.status not in (IPFabricSyncStatusChoices.SYNCING,):
             if self.snapshot_data.source.type == "remote":
                 if self.snapshot_data.ipf_data.count() > 0:
                     return True
@@ -723,7 +724,7 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
 
     def enqueue_sync_job(self, adhoc=False, user=None) -> Job | None:
         def set_syncing_status():
-            self.status = DataSourceStatusChoices.QUEUED
+            self.status = IPFabricSyncStatusChoices.QUEUED
             IPFabricSync.objects.filter(pk=self.pk).update(status=self.status)
 
         def sync_snapshots():
@@ -794,12 +795,12 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
                 f"Combination of these transform map groups failed validation. Missing maps: {missing}."
             )
 
-        if self.status == DataSourceStatusChoices.SYNCING:
+        if self.status == IPFabricSyncStatusChoices.SYNCING:
             raise SyncError("Cannot initiate sync; ingestion already in progress.")
 
         pre_sync.send(sender=self.__class__, instance=self)
 
-        self.status = DataSourceStatusChoices.SYNCING
+        self.status = IPFabricSyncStatusChoices.SYNCING
         IPFabricSync.objects.filter(pk=self.pk).update(status=self.status)
 
         # Begin Sync
@@ -875,11 +876,11 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
                 current_request.set(token.old_value)
                 active_branch.set(current_branch)
 
-            if self.status != DataSourceStatusChoices.FAILED:
-                self.status = DataSourceStatusChoices.COMPLETED
+            if self.status != IPFabricSyncStatusChoices.FAILED:
+                self.status = IPFabricSyncStatusChoices.READY_TO_MERGE
 
         except Exception as e:
-            self.status = DataSourceStatusChoices.FAILED
+            self.status = IPFabricSyncStatusChoices.FAILED
             self.logger.log_failure(f"Ingestion Failed: `{e}`", obj=ingestion)
             self.logger.log_failure(
                 f"Stack Trace: `{traceback.format_exc()}`", obj=ingestion
@@ -893,7 +894,7 @@ class IPFabricSync(IPFabricClient, JobsMixin, TagsMixin, ChangeLoggedModel):
 
         self.last_synced = timezone.now()
 
-        if self.auto_merge and self.status == DataSourceStatusChoices.COMPLETED:
+        if self.auto_merge and self.status == IPFabricSyncStatusChoices.READY_TO_MERGE:
             self.logger.log_info("Auto Merging Ingestion", obj=ingestion)
             logger.info("Auto Merging Ingestion")
             try:
@@ -927,8 +928,8 @@ class IPFabricIngestion(JobsMixin, models.Model):
 
     class Meta:
         ordering = ("pk",)
-        verbose_name = "IP Fabric Ingestion"
-        verbose_name_plural = "IP Fabric Ingestions"
+        verbose_name = _("IP Fabric Ingestion")
+        verbose_name_plural = _("IP Fabric Ingestions")
 
     def __str__(self):
         return self.name
@@ -947,7 +948,7 @@ class IPFabricIngestion(JobsMixin, models.Model):
 
     def enqueue_merge_job(self, user, remove_branch=False):
         # Set the status to "queued"
-        self.status = DataSourceStatusChoices.QUEUED
+        self.status = IPFabricSyncStatusChoices.QUEUED
         IPFabricSync.objects.filter(ipfabricingestion=self.pk).update(
             status=self.status
         )
@@ -988,12 +989,12 @@ class IPFabricIngestion(JobsMixin, models.Model):
 
     def sync_merge(self):
         ipfabricsync = self.sync
-        if ipfabricsync.status == DataSourceStatusChoices.SYNCING:
+        if ipfabricsync.status == IPFabricSyncStatusChoices.MERGING:
             raise SyncError("Cannot initiate merge; merge already in progress.")
 
         pre_sync.send(sender=self.__class__, instance=self)
 
-        ipfabricsync.status = DataSourceStatusChoices.SYNCING
+        ipfabricsync.status = IPFabricSyncStatusChoices.MERGING
         IPFabricSync.objects.filter(ipfabricingestion=self.pk).update(
             status=self.sync.status
         )
@@ -1010,9 +1011,9 @@ class IPFabricIngestion(JobsMixin, models.Model):
                 assign_virtualchassis_master, sender=VirtualChassis
             )
             signals.pre_save.disconnect(clear_other_primary_ip, sender=Device)
-            ipfabricsync.status = DataSourceStatusChoices.COMPLETED
+            ipfabricsync.status = IPFabricSyncStatusChoices.COMPLETED
         except Exception as e:
-            ipfabricsync.status = DataSourceStatusChoices.FAILED
+            ipfabricsync.status = IPFabricSyncStatusChoices.FAILED
             logger.debug(f"Merging {self.name} Failed: `{e}`")
 
         logger.debug(f"Completed merge {self.name}")
@@ -1039,8 +1040,8 @@ class IPFabricIngestionIssue(models.Model):
 
     class Meta:
         ordering = ["timestamp"]
-        verbose_name = "IP Fabric Ingestion Issue"
-        verbose_name_plural = "IP Fabric Ingestion Issues"
+        verbose_name = _("IP Fabric Ingestion Issue")
+        verbose_name_plural = _("IP Fabric Ingestion Issues")
 
     def __str__(self):
         return f"[{self.timestamp}] {self.message}"
