@@ -68,7 +68,7 @@ class IPFabricTransformMapGroupTable(NetBoxTable):
     maps_count = columns.LinkedCountColumn(
         viewname="plugins:ipfabric_netbox:ipfabrictransformmap_list",
         url_params={"group_id": "pk"},
-        verbose_name="Transform Maps",
+        verbose_name=_("Transform Maps"),
     )
 
     class Meta(NetBoxTable.Meta):
@@ -90,9 +90,11 @@ class IPFabricTransformMapTable(NetBoxTable):
 
 class IPFabricIngestionTable(NetBoxTable):
     name = tables.Column(linkify=True)
-    sync = tables.Column(verbose_name="IP Fabric Sync", linkify=True)
+    sync = tables.Column(verbose_name=_("IP Fabric Sync"), linkify=True)
     branch = tables.Column(linkify=True)
-    changes = tables.Column(accessor="staged_changes", verbose_name="Number of Changes")
+    changes = tables.Column(
+        accessor="staged_changes", verbose_name=_("Number of Changes")
+    )
     actions = columns.ActionsColumn(actions=("delete",))
 
     class Meta(NetBoxTable.Meta):
@@ -126,7 +128,7 @@ class IPFabricSnapshotTable(NetBoxTable):
 class IPFabricSourceTable(NetBoxTable):
     name = tables.Column(linkify=True)
     status = columns.ChoiceFieldColumn()
-    snapshot_count = tables.Column(verbose_name="Snapshots")
+    snapshot_count = tables.Column(verbose_name=_("Snapshots"))
     tags = columns.TagColumn(url_name="core:datasource_list")
 
     class Meta(NetBoxTable.Meta):
@@ -148,13 +150,13 @@ class IPFabricSyncTable(NetBoxTable):
     name = tables.Column(linkify=True)
     status = columns.ChoiceFieldColumn()
     snapshot_name = tables.Column(
-        verbose_name="Snapshot Name",
+        verbose_name=_("Snapshot Name"),
         accessor="snapshot_data",
         linkify=True,
     )
     last_ingestion = tables.Column(
         accessor="last_ingestion",
-        verbose_name="Last Ingestion",
+        verbose_name=_("Last Ingestion"),
         linkify=True,
     )
 
@@ -186,9 +188,9 @@ class IPFabricIngestionChangesTable(NetBoxTable):
     id = tables.Column(verbose_name=_("ID"))
     pk = None
     object_type = tables.Column(
-        accessor="object_type.model", verbose_name="Object Type"
+        accessor="object_type.model", verbose_name=_("Object Type")
     )
-    object = tables.Column(verbose_name="Object")
+    object = tables.Column(verbose_name=_("Object"))
     actions = columns.TemplateColumn(template_code=DIFF_BUTTON)
 
     def render_object(self, value, record):
@@ -225,8 +227,8 @@ class IPFabricIngestionChangesTable(NetBoxTable):
 
 class IPFabricIngestionIssuesTable(NetBoxTable):
     id = tables.Column(verbose_name=_("ID"))
-    exception = tables.Column(verbose_name="Exception Type")
-    message = tables.Column(verbose_name="Error Message")
+    exception = tables.Column(verbose_name=_("Exception Type"))
+    message = tables.Column(verbose_name=_("Error Message"))
     actions = None
 
     class Meta(NetBoxTable.Meta):
