@@ -1,9 +1,10 @@
-from core.choices import DataSourceStatusChoices
 from django.contrib.contenttypes.models import ContentType
 from django.utils import timezone
 from rest_framework import status
 from utilities.testing import APIViewTestCases
 
+from ipfabric_netbox.choices import IPFabricSourceStatusChoices
+from ipfabric_netbox.choices import IPFabricSyncStatusChoices
 from ipfabric_netbox.models import IPFabricData
 from ipfabric_netbox.models import IPFabricIngestion
 from ipfabric_netbox.models import IPFabricIngestionIssue
@@ -397,7 +398,7 @@ class IPFabricSourceTest(APIViewTestCases.APIViewTestCase):
         # Get the first source from setUpTestData
         source = IPFabricSource.objects.first()
         # Set status to make ready_for_sync return True
-        source.status = DataSourceStatusChoices.COMPLETED
+        source.status = IPFabricSourceStatusChoices.COMPLETED
         source.save()
 
         with self.settings(CELERY_TASK_ALWAYS_EAGER=True):
@@ -437,7 +438,7 @@ class IPFabricSourceTest(APIViewTestCases.APIViewTestCase):
 
         source = IPFabricSource.objects.first()
         # Set status to make ready_for_sync return False
-        source.status = DataSourceStatusChoices.SYNCING
+        source.status = IPFabricSourceStatusChoices.SYNCING
         source.save()
 
         url = f"{BASE}/source/{source.pk}/sync/"
@@ -707,7 +708,7 @@ class IPFabricSyncTest(APIViewTestCases.APIViewTestCase):
         # Get the first sync from setUpTestData
         sync = IPFabricSync.objects.first()
         # Set status and ensure snapshot has data to make ready_for_sync return True
-        sync.status = DataSourceStatusChoices.COMPLETED
+        sync.status = IPFabricSyncStatusChoices.COMPLETED
         sync.save()
 
         # Ensure the snapshot has data
@@ -753,7 +754,7 @@ class IPFabricSyncTest(APIViewTestCases.APIViewTestCase):
 
         sync = IPFabricSync.objects.first()
         # Set status to make ready_for_sync return False
-        sync.status = DataSourceStatusChoices.SYNCING
+        sync.status = IPFabricSyncStatusChoices.SYNCING
         sync.save()
 
         url = f"{BASE}/sync/{sync.pk}/sync/"
